Nikolay Sivov : shlwapi: Fix SHCreateWorkerWindowW fallback to A-call condition.

Alexandre Julliard julliard at winehq.org
Mon Mar 29 09:57:52 CDT 2010


Module: wine
Branch: master
Commit: ade553823d70a1f841d5056cbe14f5c0f1fd9335
URL:    http://source.winehq.org/git/wine.git/?a=commit;h=ade553823d70a1f841d5056cbe14f5c0f1fd9335

Author: Nikolay Sivov <nsivov at codeweavers.com>
Date:   Sat Mar 27 23:50:42 2010 +0300

shlwapi: Fix SHCreateWorkerWindowW fallback to A-call condition.

---

 dlls/shlwapi/ordinal.c |    9 ++++++---
 1 files changed, 6 insertions(+), 3 deletions(-)

diff --git a/dlls/shlwapi/ordinal.c b/dlls/shlwapi/ordinal.c
index 51c7941..8f3e29c 100644
--- a/dlls/shlwapi/ordinal.c
+++ b/dlls/shlwapi/ordinal.c
@@ -2895,16 +2895,19 @@ DWORD WINAPI WhichPlatform(void)
 HWND WINAPI SHCreateWorkerWindowW(LONG wndProc, HWND hWndParent, DWORD dwExStyle,
                         DWORD dwStyle, HMENU hMenu, LONG z)
 {
-  static const WCHAR szClass[] = { 'W', 'o', 'r', 'k', 'e', 'r', 'W', '\0' };
+  static const WCHAR szClass[] = { 'W', 'o', 'r', 'k', 'e', 'r', 'W', 0 };
   WNDCLASSW wc;
   HWND hWnd;
 
   TRACE("(0x%08x,%p,0x%08x,0x%08x,%p,0x%08x)\n",
          wndProc, hWndParent, dwExStyle, dwStyle, hMenu, z);
 
-  /* If our OS is natively ASCII, use the ASCII version */
-  if (!(GetVersion() & 0x80000000))  /* NT */
+  /* If our OS is natively ANSI, use the ANSI version */
+  if (GetVersion() & 0x80000000)  /* not NT */
+  {
+    TRACE("fallback to ANSI, ver 0x%08x\n", GetVersion());
     return SHCreateWorkerWindowA(wndProc, hWndParent, dwExStyle, dwStyle, hMenu, z);
+  }
 
   /* Create Window class */
   wc.style         = 0;




More information about the wine-cvs mailing list